pub struct UnexpectedEOF {
pub required: usize,
pub had: usize,
}Expand description
Error type to be raised when &[u8] does not have enough bytes to unpack something or when
SlicePacker does not have enough space to pack something.
Fields
required: usizeThe required number of bytes.
had: usizeThe number of bytes the unpacker had or the number of bytes the packer can receive.